@@ -12,18 +12,14 @@
 #GNU General Public License for more details
 
 #ユーザチェック
-
-if [ ! `whoami` = hinemos -a ! `whoami` = root ]; then
-    echo "hinemosまたはrootユーザで実行してください。"
+if [ ! `whoami` = hinemos ]; then
+    echo "hinemosユーザで実行してください。"
     exit 1
 fi
 
 #設定情報読み込み
 . /opt/hinemos/hinemos.cfg
 
-#ユーザ情報を読み込み
-USER=`whoami`
-
 #
 #変数
 #
@@ -31,7 +27,7 @@ SSH_KEYGEN="/usr/bin/ssh-keygen -t rsa"
 MKDIR=/bin/mkdir
 CHMOD=/bin/chmod
 
-VERSION=`cat ${HINEMOS_HOME}/_version`
+VERSION=`cat ${EXEC_PATH}/hinemos/_version`
 
 echo ""
 echo "###################################################################"
@@ -39,15 +35,15 @@ echo "###"
 echo "###              運用管理ソフトウェア Hinemos"
 echo "###            一括制御 セットアップスクリプト  Ver. ${VERSION}"
 echo "###"
-echo "###  Copyright (C) since 2006 NTT DATA Corporation."
+echo "###  Copyright (C) 2006 - 2009 NTT DATA Corporation."
 echo "###################################################################"
 
 
 
-#hinemos/rootユーザの認証用の公開鍵の作成
+#hinemosユーザの認証用の公開鍵の作成
 setup() {
     echo "" 
-    echo "${USER} ユーザの認証用の公開鍵をパスフレーズなしで作成します。"
+    echo "hinemos ユーザの認証用の公開鍵をパスフレーズなしで作成します。"
     echo "よろしいですか? (Y/N default:Y)"
     while [ 1 ];
     do
@@ -99,11 +95,11 @@ setup() {
 }
 
 
-#監視対象ノードへのhinemos/rootユーザの公開鍵の登録
+#監視対象ノードへのhinemosユーザの公開鍵の登録
 entry() {
     if [ ! -e ${HOME}/.ssh/id_rsa.pub ]; then
         echo ""
-        echo "${USER} ユーザの公開鍵が作成されていません。作成して下さい。"
+        echo "hinemosユーザの公開鍵が作成されていません。作成して下さい。"
         return
     fi
     
@@ -111,7 +107,7 @@ entry() {
 
     echo ""
     echo ""
-    echo "監視対象ノードのrootユーザのauthorized_keysファイルに、${USER} ユーザの公開鍵を登録します。"
+    echo "監視対象ノードのrootユーザのauthorized_keysファイルに、hinemosユーザの公開鍵を登録します。"
 
     while [ 1 ];
     do
@@ -146,17 +142,17 @@ entry() {
 			;;
 		esac
 		
-		echo ${ROOT_HOME}".ssh/authorized_keysに、${USER} ユーザの公開鍵を設定します。"
+		echo ${ROOT_HOME}".ssh/authorized_keysに、hinemosユーザの公開鍵を設定します。"
 		echo "よろしいですか? (Y/N default:Y)"
 		read ANS
 		ANS=${ANS:-Y}
 		AGENT_AUTHORIZED_KEYS=${ROOT_HOME}.ssh/authorized_keys
 		case ${ANS} in
 		    y|Y)
-			ssh root@${AGENT_IP} "
-                            if [ ! -d ${ROOT_HOME}.ssh ] ; then
-                                ${MKDIR} ${ROOT_HOME}.ssh
-                                ${CHMOD} 700 ${ROOT_HOME}.ssh
+			ssh root@${AGENT_IP} command "
+                            if [ ! -d ${ROOT_HOME}/.ssh ] ; then
+                                ${MKDIR} ${ROOT_HOME}/.ssh
+                                ${CHMOD} 700 ${ROOT_HOME}/.ssh
                             fi
                             echo ${MANAGER_KEY} >> ${AGENT_AUTHORIZED_KEYS}
                             ${CHMOD} 600 ${AGENT_AUTHORIZED_KEYS}
@@ -185,7 +181,7 @@ do
     echo ""
     echo "一括制御機能のセットアップ"
     echo ""
-    echo "     1) ${USER} ユーザの認証用の公開鍵の作成"
+    echo "     1) hinemosユーザの認証用の公開鍵の作成"
     echo "     2) 監視対象ノードへの公開鍵登録"
     echo "     9) 一括制御機能のセットアップ終了"
     echo ""
